#
# spec file for package ghc-http2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name http2
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        5.3.9
Release:        1.7
Summary:        HTTP/2 library
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-array-prof
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-async-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-http-semantics-devel
BuildRequires:  ghc-http-semantics-prof
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-http-types-prof
BuildRequires:  ghc-iproute-devel
BuildRequires:  ghc-iproute-prof
BuildRequires:  ghc-network-byte-order-devel
BuildRequires:  ghc-network-byte-order-prof
BuildRequires:  ghc-network-control-devel
BuildRequires:  ghc-network-control-prof
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-stm-prof
BuildRequires:  ghc-time-manager-devel
BuildRequires:  ghc-time-manager-prof
BuildRequires:  ghc-unix-time-devel
BuildRequires:  ghc-unix-time-prof
BuildRequires:  ghc-utf8-string-devel
BuildRequires:  ghc-utf8-string-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-Glob-prof
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-aeson-pretty-prof
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base16-bytestring-devel
BuildRequires:  ghc-base16-bytestring-prof
BuildRequires:  ghc-crypton-devel
BuildRequires:  ghc-crypton-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-filepath-prof
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
BuildRequires:  ghc-network-run-devel
BuildRequires:  ghc-network-run-prof
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-random-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-typed-process-devel
BuildRequires:  ghc-typed-process-prof
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-vector-prof
%endif

%description
HTTP/2 library including frames, priority queues, HPACK, client and server.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Dec  3 2024 Peter Simons <psimons@suse.com>
- Update http2 to version 5.3.9.
  [#]# 5.3.9
  * Using `ThreadManager` of `time-manager`.
  [#]# 5.3.8
  * `forkManagedTimeout` ensures that only one asynchronous exception is
    thrown. Fixing the thread leak via `Weak ThreadId` and `modifyTVar'`.
    [#156](https://github.com/kazu-yamamoto/http2/pull/156)
  [#]# 5.3.7
  * Using `withHandle` of time-manager.
  * Getting `Handle` for each thread.
  * Providing allocSimpleConfig' to enable customizing WAI tiemout manager.
  * Monitor option (-m) for h2c-client and h2c-server.
* Sat Nov 16 2024 Peter Simons <psimons@suse.com>
- Update http2 to version 5.3.6.
  [#]# 5.3.6
  * Making `runIO` friendly with the new synchronism mechanism.
    [#152](https://github.com/kazu-yamamoto/http2/pull/152)
  * Re-throwing asynchronous exceptions to prevent thread leak.
  * Simplifying the synchronism mechanism between workers and the sender.
    [#148](https://github.com/kazu-yamamoto/http2/pull/148)
  [#]# 5.3.5
  * Using `http-semantics` v0.3.
  * Deprecating `numberOfWorkers`.
  * Removing `unliftio`.
  * Avoid `undefined` in client.
    [#146](https://github.com/kazu-yamamoto/http2/pull/146)
* Thu Aug 29 2024 Peter Simons <psimons@suse.com>
- Update http2 to version 5.3.4.
  [#] ChangeLog for http2
  [#]# 5.3.4
  * Support stream cancellation
    [#142](https://github.com/kazu-yamamoto/http2/pull/142)
  [#]# 5.3.3
  * Enclosing IPv6 literal authority with square brackets.
    [#143](https://github.com/kazu-yamamoto/http2/pull/143)
  [#]# 5.3.2
  * Avoid unnecessary empty data frames at end of stream
    [#140](https://github.com/kazu-yamamoto/http2/pull/140)
  * Removing unnecessary API from ServerIO
  [#]# 5.3.1
  * Fix treatment of async exceptions
    [#138](https://github.com/kazu-yamamoto/http2/pull/138)
  * Avoid race condition
    [#137](https://github.com/kazu-yamamoto/http2/pull/137)
  [#]# 5.3.0
  * New server architecture: spawning worker on demand instead of the
    worker pool. This reduce huge numbers of threads for streaming into
    only 2. No API changes but workers do not terminate quicly. Rather
    workers collaborate with the sender after queuing a response and
    finish after all response data are sent.
  * All threads are labeled with `labelThread`. You can see them by
    `listThreas` if necessary.
  [#]# 5.2.6
  * Recover rxflow on closing.
    [#126](https://github.com/kazu-yamamoto/http2/pull/126)
  * Fixing ClientSpec for stream errors.
  * Allowing negative window. (h2spec http2/6.9.2)
  * Update for latest http-semantics
    [#122](https://github.com/kazu-yamamoto/http2/pull/124)
  [#]# 5.2.5
  * Setting peer initial window size properly.
    [#123](https://github.com/kazu-yamamoto/http2/pull/123)
  [#]# 5.2.4
  * Update for latest http-semantics
    [#122](https://github.com/kazu-yamamoto/http2/pull/122)
  * Measuring performance concurrently for h2c-client
  [#]# 5.2.3
  * Update for latest http-semantics
    [#120](https://github.com/kazu-yamamoto/http2/pull/120)
  * Enable containers 0.7 (ghc 9.10)
    [#117](https://github.com/kazu-yamamoto/http2/pull/117)
  [#]# 5.2.2
  * Mark final chunk as final
    [#116](https://github.com/kazu-yamamoto/http2/pull/116)
  [#]# 5.2.1
  * Using time-manager v0.1.0.
    [#115](https://github.com/kazu-yamamoto/http2/pull/115)
  [#]# 5.2.0
  * Using http-semantics
    [#114](https://github.com/kazu-yamamoto/http2/pull/114)
  * `Header` of `http-types` should be used as high-level header.
  * `TokenHeader` of `http-semantics` should be used as low-level header.
  * Breaking change: `encodeHeader` takes `Header` of `http-types`.
  * Breaking change: `decodeHeader` returns `Header` of `http-types`.
  * Breaking change: `HeaderName` as `ByteString` is removed.
  [#]# 5.1.4
  * Using network-control v0.1.
  [#]# 5.1.3
  * Defining SendRequest type synonym.
    [#111](https://github.com/kazu-yamamoto/http2/pull/111)
  [#]# 5.1.2
  * Make ping rate limit configurable
    [#108](https://github.com/kazu-yamamoto/http2/pull/108)
  [#]# 5.1.1
  * Deal with RST_STREAM in HalfClosedLocal state
    [#107](https://github.com/kazu-yamamoto/http2/pull/107)
  [#]# 5.1.0
  * Drop frames after reset
    [#106](https://github.com/kazu-yamamoto/http2/pull/106)
  * BREAKING CHANGE: Use String for Authority
    [#105](https://github.com/kazu-yamamoto/http2/pull/105)
  * Properly close streams
    [#104](https://github.com/kazu-yamamoto/http2/pull/104)
* Wed Dec 27 2023 Peter Simons <psimons@suse.com>
- Update http2 to version 5.0.1.
  [#]# 5.0.1
  * Allowing bytestring 0.12.
* Fri Nov 24 2023 Peter Simons <psimons@suse.com>
- Update http2 to version 5.0.0.
  [#]# 5.0.0
  * Using the network-control package.
  * The limits of resources can be specified in ServerConfig and ClientConfig.
  * Open streams based on peer's MaxStreams.
  * Rejecting Data if it is over the receiving limit.
  * Informing MaxStreams properly.
  * Informing WindowUpdate properly.
  * New API: Server.Internal.runIO and Client.Internal.runIO.
* Wed Oct 11 2023 Peter Simons <psimons@suse.com>
- Update http2 to version 4.2.2.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/http2-4.2.2/src/ChangeLog.md
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Jan 25 2022 Peter Simons <psimons@suse.com>
- Update http2 to version 3.0.3.
  [#]# 3.0.3
  * Return correct status messages in HTTP2 client
    (#31)[https://github.com/kazu-yamamoto/http2/pull/31]
  * Follow changes in Aeson 2
    (#32)[https://github.com/kazu-yamamoto/http2/pull/32]
  * Make sure connection preface is always sent first
    (#33)[https://github.com/kazu-yamamoto/http2/pull/33]
  * Avoid empty data
    (#34)[https://github.com/kazu-yamamoto/http2/pull/34]
* Thu Jun 10 2021 psimons@suse.com
- Update http2 to version 3.0.2.
  [#]# 3.0.2
  * Skip inserting entries that do not fit in the encoding table
    (#28)[https://github.com/kazu-yamamoto/http2/pull/28]
* Thu Apr 22 2021 psimons@suse.com
- Update http2 to version 3.0.1.
  [#]# 3.0.1
  * Including a necessary file for testing.
* Fri Apr 16 2021 psimons@suse.com
- Update http2 to version 3.0.0.
  [#]# 3.0.0
  * DOS preventions.
  * Providing Network.HTTP.Client.
  * `Internal` modules are exported.
  * Dropping the priority feature from Network.HTTP.Server.
  * `Network.HTTP2.Priority` is deprecated.
  * `Network.HTTP2` module is deprecated. Use `Network.HTTP2.Frame` instead.
  * Adding some tokens.
* Fri Feb 19 2021 psimons@suse.com
- Update http2 to version 2.0.6.
  [#]# 2.0.6
  * Dropping support of GHC 7.x
  [#]# 2.0.5
  * Passing the correct request
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Thu Jul  2 2020 psimons@suse.com
- Update http2 to version 2.0.5.
  Upstream has not updated the file "ChangeLog.md" since the last
  release.
* Tue Jun  9 2020 psimons@suse.com
- Add http2 at version 2.0.4.
